@@ -37,8 +37,8 @@ fn wrapper_once(delay: u8) -> String {
     wire bb_from_pin_a;
     wire bb_from_pin_z;
 
-    OFS1P3DX obuf(.D(to_pin), .CD(0), .SP(1), .SCLK(clk), .Q(bb_to_pin));
-    IFS1P3DX ibuf(.D(bb_from_pin_z), .CD(0), .SP(1), .SCLK(clk), .Q(from_pin));
+    OFS1P3DX obuf(.D(to_pin), .CD(1'b0), .SP(1'b1), .SCLK(clk), .Q(bb_to_pin));
+    IFS1P3DX ibuf(.D(bb_from_pin_z), .CD(1'b0), .SP(1'b1), .SCLK(clk), .Q(from_pin));
     BB bb(.I(bb_to_pin), .O(bb_from_pin_a), .B(pin), .T(~output_enable));
 
     defparam dg.DEL_VALUE = {delay_from_pin};
@@ -54,8 +54,8 @@ fn wrapper_multiple(count: usize, delay: u8) -> String {
         .map(|x| {
             format!(
                 r#"
-    OFS1P3DX obuf_{x}(.D(to_pin[{x}]), .CD(0), .SP(1), .SCLK(clk), .Q(bb_to_pin[{x}]));
-    IFS1P3DX ibuf_{x}(.D(bb_from_pin_z[{x}]), .CD(0), .SP(1), .SCLK(clk), .Q(from_pin[{x}]));
+    OFS1P3DX obuf_{x}(.D(to_pin[{x}]), .CD(1'b0), .SP(1'b1), .SCLK(clk), .Q(bb_to_pin[{x}]));
+    IFS1P3DX ibuf_{x}(.D(bb_from_pin_z[{x}]), .CD(1'b0), .SP(1'b1), .SCLK(clk), .Q(from_pin[{x}]));
     BB bb_{x}(.I(bb_to_pin[{x}]), .O(bb_from_pin_a[{x}]), .B(pin[{x}]), .T(~output_enable));
 
     defparam dg_from_pin_{x}.DEL_VALUE = {delay_from_pin};
