@@ -27,10 +27,12 @@ pub use crate::widgets::pwm::PulseWidthModulator;
 pub use crate::widgets::ramrom::ram::RAM;
 pub use crate::widgets::ramrom::rom::ROM;
 pub use crate::widgets::ramrom::sync_rom::SyncROM;
-pub use crate::widgets::sdram::basic_controller::{OutputBuffer, SDRAMBaseController};
+pub use crate::widgets::sdram::basic_controller::SDRAMBaseController;
+pub use crate::widgets::sdram::burst_controller::SDRAMBurstController;
 pub use crate::widgets::sdram::cmd::SDRAMCommand;
 pub use crate::widgets::sdram::fifo_sdram::SDRAMFIFOController;
 pub use crate::widgets::sdram::timings::MemoryTimings;
+pub use crate::widgets::sdram::OutputBuffer;
 pub use crate::widgets::sdram::SDRAMDriver;
 pub use crate::widgets::shot::Shot;
 pub use crate::widgets::spi::master::SPIWiresSlave;
