@@ -2,7 +2,7 @@ use crate::core::prelude::*;
 use crate::widgets::dff::DFF;
 use crate::widgets::prelude::{DelayLine, MemoryTimings};
 use crate::widgets::sdram::cmd::{SDRAMCommand, SDRAMCommandEncoder};
-use crate::widgets::sdram::SDRAMDriver;
+use crate::widgets::sdram::{OutputBuffer, SDRAMDriver};
 
 // Controller states...
 #[derive(Copy, Clone, PartialEq, Debug, LogicState)]
@@ -13,6 +13,8 @@ enum State {
     AutoRefresh2,
     LoadModeRegister,
     Idle,
+    IssueRead,
+    IssueWrite,
     Refresh,
     ReadActivate,
     ReadCycle,
@@ -59,6 +61,7 @@ pub struct SDRAMBaseController<const R: usize, const C: usize, const L: usize, c
     reg_data_write: DFF<Bits<L>>,
     reg_data_read: DFF<Bits<L>>,
     reg_address: DFF<Bits<32>>,
+    reg_cmd_address: DFF<Bits<32>>,
     delay_counter: DFF<Bits<16>>,
     refresh_counter: DFF<Bits<16>>,
     transfer_counter: DFF<Bits<5>>,
@@ -77,13 +80,6 @@ pub struct SDRAMBaseController<const R: usize, const C: usize, const L: usize, c
     data_out_counter: DFF<Bits<5>>,
 }
 
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum OutputBuffer {
-    Wired,
-    DelayOne,
-    DelayTwo,
-}
-
 impl<const R: usize, const C: usize, const L: usize, const D: usize>
     SDRAMBaseController<R, C, L, D>
 {
@@ -140,6 +136,7 @@ impl<const R: usize, const C: usize, const L: usize, const D: usize>
             reg_data_write: Default::default(),
             reg_data_read: Default::default(),
             reg_address: Default::default(),
+            reg_cmd_address: Default::default(),
             delay_counter: Default::default(),
             refresh_counter: Default::default(),
             transfer_counter: Default::default(),
@@ -180,6 +177,8 @@ impl<const R: usize, const C: usize, const L: usize, const D: usize> Logic
         self.data_out_counter.clk.next = self.clock.val();
         self.read_ready.clk.next = self.clock.val();
         self.refresh_needed.clk.next = self.clock.val();
+        self.reg_cmd_address.clk.next = self.clock.val();
+        self.reg_cmd_address.d.next = self.reg_cmd_address.q.val();
         // Latch prevention
         self.state.d.next = self.state.q.val();
         self.delay_counter.d.next = self.delay_counter.q.val() + 1_usize;
@@ -265,21 +264,29 @@ impl<const R: usize, const C: usize, const L: usize, const D: usize> Logic
                     self.refresh_counter.d.next = 0_usize.into();
                     self.refresh_needed.d.next = false;
                 } else if self.read_pending.q.val() {
-                    self.cmd.next = SDRAMCommand::Active;
-                    self.sdram.bank.next = self.addr_bank.val();
-                    self.sdram.address.next = self.addr_row.val();
-                    self.state.d.next = State::ReadActivate;
-                    self.read_pending.d.next = false;
-                    self.data_out_counter.d.next = 0_u8.into();
+                    self.reg_address.d.next = self.reg_cmd_address.q.val();
+                    self.state.d.next = State::IssueRead;
                 } else if self.write_pending.q.val() {
-                    self.cmd.next = SDRAMCommand::Active;
-                    self.sdram.bank.next = self.addr_bank.val();
-                    self.sdram.address.next = self.addr_row.val();
-                    self.state.d.next = State::WriteActivate;
-                    self.write_pending.d.next = false;
-                    self.sdram.write_enable.next = true;
+                    self.reg_address.d.next = self.reg_cmd_address.q.val();
+                    self.state.d.next = State::IssueWrite;
                 }
             }
+            State::IssueRead => {
+                self.cmd.next = SDRAMCommand::Active;
+                self.sdram.bank.next = self.addr_bank.val();
+                self.sdram.address.next = self.addr_row.val();
+                self.state.d.next = State::ReadActivate;
+                self.read_pending.d.next = false;
+                self.data_out_counter.d.next = 0_u8.into();
+            }
+            State::IssueWrite => {
+                self.cmd.next = SDRAMCommand::Active;
+                self.sdram.bank.next = self.addr_bank.val();
+                self.sdram.address.next = self.addr_row.val();
+                self.state.d.next = State::WriteActivate;
+                self.write_pending.d.next = false;
+                self.sdram.write_enable.next = true;
+            }
             State::Refresh => {
                 if self.delay_counter.q.val() == self.t_rfc.val() {
                     self.state.d.next = State::Idle;
@@ -345,7 +352,7 @@ impl<const R: usize, const C: usize, const L: usize, const D: usize> Logic
         self.error.next = self.state.q.val() == State::Error;
         // Handle the input command latching
         if self.cmd_strobe.val() & !self.read_pending.q.val() & !self.write_pending.q.val() {
-            self.reg_address.d.next = self.cmd_address.val();
+            self.reg_cmd_address.d.next = self.cmd_address.val();
             if self.write_not_read.val() {
                 self.write_pending.d.next = true;
                 self.reg_data_write.d.next = self.data_in.val();
