@@ -23,9 +23,12 @@ impl<D: Synth> Logic for TristateBuffer<D> {
     }
 
     fn hdl(&self) -> Verilog {
-        Verilog::Custom(format!("\
+        Verilog::Custom(format!(
+            "\
     assign bus = write_enable ? write_data : {WIDTH}'bz;
-always @(*) read_data = bus;", WIDTH = D::BITS))
+always @(*) read_data = bus;",
+            WIDTH = D::BITS
+        ))
     }
 }
 
@@ -38,4 +41,4 @@ fn test_tristate_synthesizes() {
     let vlog = generate_verilog(&uut);
     println!("{}", vlog);
     yosys_validate("tristate", &vlog).unwrap()
-}
\ No newline at end of file
+}
